@@ -21,7 +21,7 @@
 
 #include <sonnet/speller.h>
 
-#include <plasma/abstractrunner.h>
+#include <KRunner/AbstractRunner>
 #include <QSharedPointer>
 
 /**
@@ -55,6 +55,4 @@ private:
     QMutex m_spellLock; //Lock held when constructing a new speller
 };
 
-K_EXPORT_PLASMA_RUNNER(spellcheckrunner, SpellCheckRunner)
-
 #endif
